
##########################################################
#
#  EXAMPLE usage of LWP-Trends functions 
#  As provided in the 2020 Trends Guidance document
#
##########################################################

#This file provides XXX example applciations of the LWP-Trends code
#The five applications are for:
#   1. Monthly observations (a) Seasonal and (b) non-seasonal (TN)
#   2. Annual Observations/ MCI
#   3. Monthly observations with gaps (so analysed quarterly) (NO3N)
#   4. Changing censor levels


# Date: DEcember 2020
# By Caroline Fraser and Ton Snelder
##########################################################

rm(list = ls())   

require(ggplot2)
require(cowplot)

#Define the location where you have saved the exmaple datasets
dir.data<-"D:\\Harris Consulting\\TrendAssessementGuidance - Documents\\Worked Example"
#Define the location where you have save the LWPTrends code
dir.code<-"D:\\Harris Consulting\\Common Data and Code - Documents\\WQAnalysis\\R_TrendAnalysisFunctions\\"  #"D:/SharePoint/Common Data and Code - Documents/WQAnalysis/R_TrendAnalysisFunctions/"#getwd() #UPDATE TO LOCAL DIRECTORY

##########################################################
setwd(dir.code)
source("LWPTrends_v2001.r")
setwd(dir.data)

##########################################################
#    Example 1
##########################################################

Ex1<-read.csv("Example1.csv")
#Example 1:
Ex1$myDate <- as.Date(as.character(Ex1$myDate),"%d/%m/%Y")
#Add on additional date information  
Ex1<-GetMoreDateInfo(Ex1)

#We will set season to meonthly for the purposes of plotting and exploring the data
Ex1$Season <- factor(Ex1$Month, NumMonthString)

#Process censored values
NewValues <- RemoveAlphaDetect(Ex1$Value)
Ex1 <- cbind.data.frame(Ex1, NewValues)



summary(Ex1) # note there are 2 censored values (Censored == TRUE)
#check to see an appropraiate start year to look at the data
min(Ex1$myDate)
myStartYear=1993

#Make a plot showing a data summary
Ex1_Inspection<-InspectData(Ex1, StartYear = myStartYear, EndYear = 2017,
                             plotType = "All_GGPlot",SiteName="Example 1")
Ex1_Inspection[[1]]##### The dataframe of results
x11();Ex1_Inspection[[2]][[1]]  #Time series
x11();Ex1_Inspection[[2]][[2]]  #Matrix of observations
x11();Ex1_Inspection[[2]][[3]]  #Matrix of censoring

#The plots suggest that the data has no gaps over the 25 year period of monthly observations
# We can keep the months as season assessment

# Check for relationship of observations with flow.
#Flow Adjustment
Ex1_FlowAdjusted<-AdjustValues(Ex1, method = c("Gam", "LogLog", "LOESS"), ValuesToAdjust = "RawValue", 
                               Covariate = "Flow", Span = c(0.7, 0.9), doPlot = "doGGPlot",plotpval = TRUE)
#Ex2_FlowAdjusted[[2]] contains the dataframe of adjusted values
x11();Ex1_FlowAdjusted[[2]]  ### Flow adjustement scatter plot

#Select which flow adjustment to use (note, this could be different for every site/variable combination)
Ex1<-merge(Ex1,Ex1_FlowAdjusted[[1]][,c("myDate","LOESS0.9")])
names(Ex1)[names(Ex1)=="LOESS0.9"]<-"FlowAdjusted"

#CHeck seasonality
#Seasonality Test on Raw Data
Ex1_SeasonalityRAW<-SeasonalityTest(Ex1,SiteName="Example 1: Raw Values",ValuesToUse = "RawValue",do.plot="doGGPlot")
Ex1_SeasonalityRAW[[1]]##### The dataframe of results
x11();Ex1_SeasonalityRAW[[2]]##### The boxplot of data by seasons

#Seasonality Test on Flow Adjusted Data
Ex1_SeasonalityFA<-SeasonalityTest(Ex1,SiteName="Example 1: Flow Adjusted Values",ValuesToUse = "FlowAdjusted",
                                   do.plot="doGGPlot",RawValues = FALSE)
Ex1_SeasonalityFA[[1]]##### The dataframe of results
x11();Ex1_SeasonalityFA[[2]]##### The boxplot of data by seasons

#Evaluate seasonal flow adjusted trend
Ex1_SeasFATrend<-SeasonalTrendAnalysis(Ex1,mymain="Ex 1 FA Trend: Monthly Data",ValuesToUse="FlowAdjusted",
                                      doPlot="doGGPlot",RawValues=FALSE)
#Examine the vlaues
Ex1_SeasFATrend[[1]]
x11();Ex1_SeasFATrend[[2]]

#For comparison, evaluate seaonal rawvalue trend
Ex1_SeasRawTrend<-SeasonalTrendAnalysis(Ex1,mymain="Ex 1 Raw Trend: Monthly Data",ValuesToUse="RawValue",
                                       doPlot="doGGPlot")
#Examine the vlaues
Ex1_SeasRawTrend[[1]]
x11();Ex1_SeasRawTrend[[2]]

#####################################################
# Example 2: MCI data
#####################################################

Ex2<-read.csv("Example2.csv")

#Example 2:
Ex2$myDate <- as.Date(as.character(Ex2$myDate),"%d/%m/%Y")
#Add on additional date information  
Ex2<-GetMoreDateInfo(Ex2)

#We will set season to monthly for the purposes of plotting and exploring the data
Ex2$Season <- factor(Ex2$Month, NumMonthString)

#Process censored values
NewValues <- RemoveAlphaDetect(Ex2$Value)
Ex2 <- cbind.data.frame(Ex2, NewValues)

summary(Ex2) # note there are NO censored values (Censored == TRUE)
#check to see an appropraiate start year to look at the data
min(Ex2$myDate)
myStartYear=1995

#Make a plot showing a data summary
Ex2_Inspection<-InspectData(Ex2, StartYear = myStartYear, EndYear = 2017,
                            plotType = "All_GGPlot",SiteName="Example 2")
Ex2_Inspection[[1]]##### The dataframe of results
x11();Ex2_Inspection[[2]][[1]]  #Time series - note there are lot of what look like duplicates
x11();Ex2_Inspection[[2]][[2]]  #Matrix of observations
#Note don't show censoring plot as we have already observed there are no censored values

#Need to maake some choices about seasons
#Read in cleaned dataset (there were some duplicates in the raw set that were manually removed)
Ex2<-read.csv("Example2 - Clean.csv")
Ex2$myDate <- as.Date(as.character(Ex2$myDate),"%d/%m/%Y")
#Add on additional date information  
Ex2<-GetMoreDateInfo(Ex2)
#Define new season as TwiceAnnual
Ex2$TwiceAnnual<-factor(ceiling(as.numeric(format(Ex2$myDate, "%m"))/6),
                        levels=1:2,labels=c("Q1Q2","Q3Q4")) #Note - do not use "-" in season deinitions
Ex2$Season<-Ex2$TwiceAnnual
#Process censored values
NewValues <- RemoveAlphaDetect(Ex2$Value)
Ex2 <- cbind.data.frame(Ex2, NewValues)

#Make a plot showing a data summary
Ex2_Inspection<-InspectData(Ex2, StartYear = myStartYear, EndYear = 2017,
                            plotType = "All_GGPlot",SiteName="Example 2")
Ex2_Inspection[[1]]##### The dataframe of results
x11();Ex2_Inspection[[2]][[1]]  #Time series
x11();Ex2_Inspection[[2]][[2]]  


#No need to flow adjust
#BUT, for TwiceAnnual seasons, need to check for seasonality

Ex2_SeasonalityTwAn<-SeasonalityTest(Ex2,SiteName="Example 2: Raw Values",ValuesToUse = "RawValue",do.plot="doGGPlot")
Ex2_SeasonalityTwAn[[1]]##### The dataframe of results
x11();Ex2_SeasonalityTwAn[[2]]##### The boxplot of data by seasons

#Evaluate seasonaltwice annual  trend
Ex2_SeasTwAnTrend<-SeasonalTrendAnalysis(Ex2,mymain="Ex 2 Trend: Twice Annual Data",ValuesToUse="RawValue",
                                       doPlot="doGGPlot")
#Examine the vlaues
Ex2_SeasTwAnTrend[[1]]
x11();Ex2_SeasTwAnTrend[[2]]

##############################################
#  Example 3: Missing data
###########################
Ex3<-read.csv("Example3.csv")

#Example 2:
Ex3$myDate <- as.Date(as.character(Ex3$myDate),"%d/%m/%Y")
#Add on additional date information  
Ex3<-GetMoreDateInfo(Ex3)

#We will set season to monthly for the purposes of plotting and exploring the data
Ex3$Season <- factor(Ex3$Month, NumMonthString)

#Process censored values
NewValues <- RemoveAlphaDetect(Ex3$Value)
Ex3 <- cbind.data.frame(Ex3, NewValues)

summary(Ex3) # note there are NO censored values (Censored == TRUE)
#check to see an appropriate start year to look at the data
min(Ex3$myDate)
myStartYear=2008

#Make a plot showing a data summary
Ex3_Inspection<-InspectData(Ex3, StartYear = myStartYear, EndYear = 2017,
                            plotType = "All_GGPlot",SiteName="Example 3")
Ex3_Inspection[[1]]##### The dataframe of results
x11();Ex3_Inspection[[2]][[1]]  #Time series
x11();Ex3_Inspection[[2]][[2]]  #Matrix of observations
#Note don't show censoring plot as we have already observed there are no censored values
#There are a lot of missing values.  We are likely to not meet our filtering requirements

# Check for relationship of observations with flow.
#Flow Adjustment
Ex3_FlowAdjusted<-AdjustValues(Ex3, method = c("Gam", "LogLog", "LOESS"), ValuesToAdjust = "RawValue", 
                               Covariate = "Flow", Span = c(0.7, 0.9), doPlot = "doGGPlot",plotpval = TRUE)
#Ex2_FlowAdjusted[[2]] contains the dataframe of adjusted values
x11();Ex3_FlowAdjusted[[2]]  ### Flow adjustement scatter plot
#No need to flow adjust

#For comparison, evaluate rawvalue trend with monhtly data
Ex3_Seasonality_1<-SeasonalityTest(Ex3,SiteName="Example 3: Raw Values",ValuesToUse = "RawValue",do.plot="doGGPlot")
Ex3_Seasonality_1[[1]]##### The dataframe of results
x11();Ex3_Seasonality_1[[2]]##### The boxplot of data by seasons
#Not seasonal as p>0.05

Ex3_RawTrend_1<-NonSeasonalTrendAnalysis(Ex3,mymain="Ex 3 Raw Trend: Monthly Data with gaps",ValuesToUse="RawValue",
                                       doPlot="doGGPlot")
#Examine the values
Ex3_RawTrend_1[[1]]
x11();Ex3_RawTrend_1[[2]]
#BUT!!  We probably don't meet the filtering rules, try bimonthly
Ex3$Season <- factor(Ex3$BiMonth, NumBiMonthString)

#Make a plot showing a data summary
Ex3_Inspection_2<-InspectData(Ex3, StartYear = myStartYear, EndYear = 2017,
                            plotType = "All_GGPlot",SiteName="Example 3")
Ex3_Inspection_2[[1]]##### The dataframe of results
x11();Ex3_Inspection_2[[2]][[1]]  #Time series
x11();Ex3_Inspection_2[[2]][[2]]  

#Evaluate rawvalue trend with bimonthly data
Ex3_Seasonality_2<-SeasonalityTest(Ex3,SiteName="Example 3: Raw Values",ValuesToUse = "RawValue",do.plot="doGGPlot")
Ex3_Seasonality_2[[1]]##### The dataframe of results
x11();Ex3_Seasonality_2[[2]]##### The boxplot of data by seasons
#Not seasonal as p>0.05

Ex3_RawTrend_2<-NonSeasonalTrendAnalysis(Ex3,mymain="Ex 3 Raw Trend: BiMonthly aggregated data",ValuesToUse="RawValue",
                                         doPlot="doGGPlot")
#Examine the vlaues
Ex3_RawTrend_2[[1]]
x11();Ex3_RawTrend_2[[2]]

###For comparison, we also have the "complete" dataset (i.e. no gaps in the data)

Ex3A<-read.csv("Example3 - complete.csv")

#Example 2:
Ex3A$myDate <- as.Date(as.character(Ex3A$myDate),"%d/%m/%Y")
#Add on additional date information  
Ex3A<-GetMoreDateInfo(Ex3A)

#We will set season to monthly 
Ex3A$Season <- factor(Ex3A$Month, NumMonthString)

#Process censored values
NewValues <- RemoveAlphaDetect(Ex3A$Value)
Ex3A <- cbind.data.frame(Ex3A, NewValues)

summary(Ex3A) # note there are NO censored values (Censored == TRUE)
#check to see an appropraiate start year to look at the data
min(Ex3A$myDate)
myStartYear=2008

#Make a plot showing a data summary
Ex3_InspectionA<-InspectData(Ex3A, StartYear = myStartYear, EndYear = 2017,
                            plotType = "All_GGPlot",SiteName="Example 3")
Ex3_InspectionA[[1]]##### The dataframe of results
x11();Ex3_InspectionA[[2]][[1]]  #Time series
x11();Ex3_InspectionA[[2]][[2]]  #Matrix of observations
#Note don't show censoring plot as we have already observed there are no censored values


# Check for relationship of observations with flow.
#Flow Adjustment
Ex3_FlowAdjustedA<-AdjustValues(Ex3A, method = c("Gam", "LogLog", "LOESS"), ValuesToAdjust = "RawValue", 
                               Covariate = "Flow", Span = c(0.7, 0.9), doPlot = "doGGPlot",plotpval = TRUE)
#Ex2_FlowAdjusted[[2]] contains the dataframe of adjusted values
x11();Ex3_FlowAdjustedA[[2]]  ### Flow adjustement scatter plot

#No need to flow adjust

# Evaluate rawvalue trend with complte monthly dataset
Ex3_SeasonalityA<-SeasonalityTest(Ex3A,SiteName="Example 3: Raw Values (complete)",ValuesToUse = "RawValue",do.plot="doGGPlot")
Ex3_SeasonalityA[[1]]##### The dataframe of results
x11();Ex3_SeasonalityA[[2]]##### The boxplot of data by seasons
#Not seasonal as p>0.05

Ex3_RawTrendA<-NonSeasonalTrendAnalysis(Ex3A,mymain="Ex 3 Raw Trend: Monthly Data complete",ValuesToUse="RawValue",
                                         doPlot="doGGPlot")
#Examine the vlaues
Ex3_RawTrendA[[1]]
x11();Ex3_RawTrendA[[2]]
###############################################


#  Example 4

Ex4<-read.csv("Example4.csv")

Ex4$myDate <- as.Date(as.character(Ex4$myDate),"%d/%m/%Y")
#Add on additional date information  
Ex4<-GetMoreDateInfo(Ex4)

#We will set season to monthly for the purposes of plotting and exploring the data
Ex4$Season <- factor(Ex4$Month, NumMonthString)

#Process censored values - use "Value" dataset
NewValues <- RemoveAlphaDetect(Ex4$Value)
Ex4 <- cbind.data.frame(Ex4, NewValues)

summary(Ex4) # note there are 44 censored values (Censored == TRUE)
#check to see an appropraiate start year to look at the data
min(Ex4$myDate)
myStartYear=2008

#Make a plot showing a data summary
Ex4_Inspection<-InspectData(Ex4, StartYear = myStartYear, EndYear = 2017,
                            plotType = "All_GGPlot",SiteName="Example 4")
Ex4_Inspection[[1]]##### The dataframe of results
x11();Ex4_Inspection[[2]][[1]]  #Time series - note the step change in detection limit from high to low
x11();Ex4_Inspection[[2]][[2]]  #Matrix of observations
x11();Ex4_Inspection[[2]][[3]]  #Matrix of censoring

#Check for seasonality
Ex4_Seasonality<-SeasonalityTest(Ex4,SiteName="Example 4: Raw Values",ValuesToUse = "RawValue",do.plot="doGGPlot")
Ex4_Seasonality[[1]]##### The dataframe of results
x11();Ex4_Seasonality[[2]]##### The boxplot of data by seasons

#Data is not seasonal, perofrm non-seasonl trend analysis
Ex4_RawTrend_hilo<-SeasonalTrendAnalysis(Ex4,mymain="Ex 4 Raw Trend: Monthly Data",ValuesToUse="RawValue",
                                       doPlot="doGGPlot")
#Examine the vlaues
Ex4_RawTrend_hilo[[1]]
x11();Ex4_RawTrend_hilo[[2]]

#Data is not seasonal, perform non-seasonl trend analysis with hicensor filter on
Ex4_RawTrendHiCen_hilo<-SeasonalTrendAnalysis(Ex4,mymain="Ex 4 Raw Trend: Monthly Data (with hi censor filter)",ValuesToUse="RawValue",
                                       doPlot="doGGPlot",HiCensor=TRUE)
#Examine the vlaues
Ex4_RawTrendHiCen_hilo[[1]]
x11();Ex4_RawTrendHiCen_hilo[[2]]

#Redo the analysis using the next dataset (no censoring)
Ex4<-read.csv("Example4.csv")
Ex4$myDate <- as.Date(as.character(Ex4$myDate),"%d/%m/%Y")
#Add on additional date information  
Ex4<-GetMoreDateInfo(Ex4)
#We will set season to monthly for the purposes of plotting and exploring the data
Ex4$Season <- factor(Ex4$Month, NumMonthString)

#Process censored values  - use "Value2" dataset (no censoring)
NewValues <- RemoveAlphaDetect(Ex4$Value2)
Ex4 <- cbind.data.frame(Ex4, NewValues)

Ex4_RawTrend_complete<-SeasonalTrendAnalysis(Ex4,mymain="Ex 4 Raw Trend: Monthly Data (complete)",ValuesToUse="RawValue",
                                    doPlot="doGGPlot")
#Examine the vlaues
Ex4_RawTrend_complete[[1]]
x11();Ex4_RawTrend_complete[[2]]


#Redo the analysis with the next dataset (detecton limit changes from low to high)
Ex4<-read.csv("Example4.csv")
Ex4$myDate <- as.Date(as.character(Ex4$myDate),"%d/%m/%Y")
#Add on additional date information  
Ex4<-GetMoreDateInfo(Ex4)
#We will set season to meonthly for the purposes of plotting and exploring the data
Ex4$Season <- factor(Ex4$Month, NumMonthString)

#Process censored values
NewValues <- RemoveAlphaDetect(Ex4$Value1)
Ex4 <- cbind.data.frame(Ex4, NewValues)

Ex4_RawTrend_lohi<-SeasonalTrendAnalysis(Ex4,mymain="Ex 4 Raw Trend: Monthly Data ('Value1' dataset)",ValuesToUse="RawValue",
                                             doPlot="doGGPlot")
#Examine the vlaues
Ex4_RawTrend_lohi[[1]]
x11();Ex4_RawTrend_lohi[[2]]

##################################################


